
/* 
 * Copyright (c) 1993-2005 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/


#ifndef regionMap_TCLSERV_CLIENT_ERROR_H
#define regionMap_TCLSERV_CLIENT_ERROR_H

#include <server/regionMapError.h>

/* -- MODULES ERRORS -------------------------------------------------- */

enum regionMap_error {
	E_regionMap_OK					  			= 0,

	/* module errors */
	E_regionMap_NOT_CONNECTED                  = S_regionMap_NOT_CONNECTED,
	E_regionMap_BAD_DISPLAY_PARAMS             = S_regionMap_BAD_DISPLAY_PARAMS,
	E_regionMap_OPEN_FILE_FAILED               = S_regionMap_OPEN_FILE_FAILED,
	E_regionMap_CALIFE_ERROR                   = S_regionMap_CALIFE_ERROR,
	E_regionMap_NO_CONNECTION_POSSIBLE         = S_regionMap_NO_CONNECTION_POSSIBLE,
	E_regionMap_CAN_NOT_UPDATE_POSTER          = S_regionMap_CAN_NOT_UPDATE_POSTER,
	E_regionMap_FUSION_ERROR                   = S_regionMap_FUSION_ERROR,
	E_regionMap_IMAGE3D_ERROR                  = S_regionMap_IMAGE3D_ERROR,
	E_regionMap_NOT_CONNECTED_TO_3D_DATA       = S_regionMap_NOT_CONNECTED_TO_3D_DATA,
	E_regionMap_CAN_NOT_READ_POSTER            = S_regionMap_CAN_NOT_READ_POSTER,
	E_regionMap_POM_POSTER_NOT_FOUND           = S_regionMap_POM_POSTER_NOT_FOUND,
	E_regionMap_ERROR_IN_LIBRARY               = S_regionMap_ERROR_IN_LIBRARY,
	E_regionMap_BAD_PROBABILITY_VALUE          = S_regionMap_BAD_PROBABILITY_VALUE,
	E_regionMap_NEGATIVE_RADIUS                = S_regionMap_NEGATIVE_RADIUS,
	E_regionMap_RMAP_CAN_NOT_SAVE_MAP          = S_regionMap_RMAP_CAN_NOT_SAVE_MAP,
	E_regionMap_RMAP_CAN_NOT_OPEN_FILE         = S_regionMap_RMAP_CAN_NOT_OPEN_FILE,
	E_regionMap_NO_MAP_STRUCTURE_INITIALIZED   = S_regionMap_NO_MAP_STRUCTURE_INITIALIZED,
	E_regionMap_CAN_NOT_LOAD_FILE              = S_regionMap_CAN_NOT_LOAD_FILE,
	E_regionMap_CAN_NOT_CREATE_IM3D            = S_regionMap_CAN_NOT_CREATE_IM3D,
	E_regionMap_POSTER_NOT_FOUND               = S_regionMap_POSTER_NOT_FOUND,
	E_regionMap_CAN_NOT_CONNECT                = S_regionMap_CAN_NOT_CONNECT,
	E_regionMap_CAN_NOT_READ_PROTO_FILE        = S_regionMap_CAN_NOT_READ_PROTO_FILE,
	E_regionMap_CAN_NOT_OPEN_FILE              = S_regionMap_CAN_NOT_OPEN_FILE,
	E_regionMap_CAN_NOT_ALLOCATE_PROTO_STRUCTURE = S_regionMap_CAN_NOT_ALLOCATE_PROTO_STRUCTURE,
	E_regionMap_CAN_NOT_ALLOCATE_MAP           = S_regionMap_CAN_NOT_ALLOCATE_MAP,
	E_regionMap_BAD_INIT_PARAMS                = S_regionMap_BAD_INIT_PARAMS,


	/* std errors */
	E_regionMap_ACTIVITY_INTERRUPTED           = S_regionMap_stdGenoM_ACTIVITY_INTERRUPTED,
	E_regionMap_TOO_MANY_ACTIVITIES            = S_regionMap_stdGenoM_TOO_MANY_ACTIVITIES,
	E_regionMap_ACTIVITY_FAILED                = S_regionMap_stdGenoM_ACTIVITY_FAILED,
	E_regionMap_WAIT_ABORT_ZOMBIE_ACTIVITY     = S_regionMap_stdGenoM_WAIT_ABORT_ZOMBIE_ACTIVITY,
	E_regionMap_UNKNOWN_ACTIVITY               = S_regionMap_stdGenoM_UNKNOWN_ACTIVITY,
	E_regionMap_FORBIDDEN_ACTIVITY_TRANSITION  = S_regionMap_stdGenoM_FORBIDDEN_ACTIVITY_TRANSITION,
	E_regionMap_SYSTEM_ERROR                   = S_regionMap_stdGenoM_SYSTEM_ERROR,
	E_regionMap_ACTIVITY_ALREADY_ENDED         = S_regionMap_stdGenoM_ACTIVITY_ALREADY_ENDED,
	E_regionMap_WAIT_INIT_RQST                 = S_regionMap_stdGenoM_WAIT_INIT_RQST,
	E_regionMap_CONTROL_CODEL_ERROR            = S_regionMap_stdGenoM_CONTROL_CODEL_ERROR,
	E_regionMap_EXEC_TASK_SUSPENDED            = S_regionMap_stdGenoM_EXEC_TASK_SUSPENDED,
	E_regionMap_BAD_BLOCK_TYPE                 = S_regionMap_stdGenoM_BAD_BLOCK_TYPE,
	E_regionMap_BAD_POSTER_TYPE                = S_regionMap_stdGenoM_BAD_POSTER_TYPE,

};

typedef enum regionMap_error regionMap_error_t;

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Take an error string in parameter, and try to get the error index associated
 * to this string
 * Returns -1 in failure case (and err is not set)
 * Returns 0 in success case (and err has a sensitive value)
 */
int regionMap_decode_error(const char* str, int *err);

/*
 * Take an integer representing an error, and try to get its textual
 * representation, in the regionMap context.
 *
 * Returns NULL in case of failure
 */
const char* regionMap_error_str(int err);

#ifdef __cplusplus
}
#endif


/*-------------------------- end file loading ---------------------------*/
#endif
